@@ -51,7 +51,7 @@ import java.util.NoSuchElementException;
  * </p>
  *
  * @author Eric D. Friedman
- * @version $Id: TLinkedList.java,v 1.12 2007/11/01 16:08:14 robeden Exp $
+ * @version $Id: TLinkedList.java,v 1.13 2008/05/05 22:49:19 robeden Exp $
  * @see gnu.trove.TLinkable
  */
 
@@ -471,7 +471,7 @@ public class TLinkedList<T extends TLinkable> extends AbstractSequentialList<T>
             newElement.setPrevious(current);
             newElement.setNext(n);
             current.setNext(newElement);
-            n.setPrevious(current);
+            n.setPrevious(newElement);
             _size++;
         }
     }
