@@ -19,6 +19,9 @@
 package gnu.trove;
 
 import java.util.Arrays;
+import java.io.ObjectOutput;
+import java.io.IOException;
+import java.io.ObjectInput;
 
 
 /**
@@ -27,9 +30,11 @@ import java.util.Arrays;
  * Created: Sun Nov  4 08:56:06 2001
  *
  * @author Eric D. Friedman
- * @version $Id: TObjectHash.java,v 1.25 2007/03/30 20:53:22 robeden Exp $
+ * @version $Id: TObjectHash.java,v 1.26 2008/05/07 21:25:45 robeden Exp $
  */
-abstract public class TObjectHash<T> extends THash implements TObjectHashingStrategy<T> {
+abstract public class TObjectHash<T> extends THash
+    implements TObjectHashingStrategy<T> {
+
     static final long serialVersionUID = -3461112548087185871L;
 
 
@@ -337,4 +342,30 @@ abstract public class TObjectHash<T> extends THash implements TObjectHashingStra
                                            + "object #1 =" + o1
                                            + "; object #2 =" + o2);
     }
+
+
+    @Override
+    public void writeExternal( ObjectOutput out ) throws IOException {
+        super.writeExternal( out );
+
+        // VERSION
+        out.writeByte( 0 );
+
+        // HASHING STRATEGY
+        out.writeObject( _hashingStrategy );
+    }
+
+    @Override
+    public void readExternal( ObjectInput in )
+        throws IOException, ClassNotFoundException {
+
+        super.readExternal( in );
+
+        // VERSION
+        in.readByte();
+
+        // HASHING STRATEGY
+        //noinspection unchecked
+        _hashingStrategy = ( TObjectHashingStrategy<T> ) in.readObject();
+    }
 } // TObjectHash
