@@ -27,7 +27,7 @@ import java.util.*;
  * Created: Sat Nov 10 15:57:07 2001
  *
  * @author Eric D. Friedman
- * @version $Id: TLinkedListTest.java,v 1.5 2007/11/01 16:01:09 robeden Exp $
+ * @version $Id: TLinkedListTest.java,v 1.6 2008/05/05 22:49:19 robeden Exp $
  */
 
 public class TLinkedListTest extends TestCase {
@@ -424,6 +424,7 @@ public class TLinkedListTest extends TestCase {
 
         System.out.println("List: " + list);
 
+        // Iterate forward
         int value = -1;
         Data cur = list.getFirst();
         while( cur != null ) {
@@ -434,25 +435,37 @@ public class TLinkedListTest extends TestCase {
         }
 
         assertEquals( 6, value );
+
+        // Iterate backward
+        value = 7;
+        cur = list.getLast();
+        while( cur != null ) {
+            assertEquals( value - 1, cur._val );
+            value = cur._val;
+
+            cur = cur.getPrevious();
+        }
+
+        assertEquals( 0, value );
     }
 
     public void testAddAfter() {
         Data one = new Data( 1 );
         Data three = new Data( 3 );
-        Data four = new Data( 4 );
         Data five = new Data( 5 );
 
         list.add( one );
         list.add( three );
-        list.add( four );
         list.add( five );
 
-        list.addBefore( one, new Data( 0 ) );
-        list.addBefore( three, new Data( 2 ) );
-        list.addBefore( null, new Data( 6 ) );
+        list.addAfter( one, new Data( 2 ) );
+        list.addAfter( three, new Data( 4 ) );
+        list.addAfter( five, new Data( 6 ) );
+        list.addAfter( null, new Data( 0 ) );
 
         System.out.println("List: " + list);
 
+        // Iterate forward
         int value = -1;
         Data cur = list.getFirst();
         while( cur != null ) {
@@ -463,6 +476,19 @@ public class TLinkedListTest extends TestCase {
         }
 
         assertEquals( 6, value );
+
+        // Iterate backward
+        value = 7;
+        cur = list.getLast();
+        while( cur != null ) {
+            System.out.println("Itr back: " + cur._val);
+            assertEquals( value - 1, cur._val );
+            value = cur._val;
+
+            cur = cur.getPrevious();
+        }
+
+        assertEquals( 0, value );
     }
 
     public void testPastIndexGet() {
